[gnus git] branch master updated: m0-5-162-g3236430 =1= gnus-diary.el (nndiary-request-create-group-functions, nndiary-request-update-info-functions, gnus-subscribe-newsgroup-functions, nndiary-request-accept-article-functions): Use new names for hooks rather than obsolete aliases

Katsumi Yamaoka <[email protected]>
Newsgroups gmane.emacs.gnus.cvs
Message-ID <[email protected]>
       via  3236430315a21e88adc7984e2634bc8b30c13fe3 (commit)
      from  e16e2dccfd04eb33d02bcae0e2cacdfee0bccbd7 (commit)


- Log -----------------------------------------------------------------
commit 3236430315a21e88adc7984e2634bc8b30c13fe3
Author: Glenn Morris <[email protected]>
Date:   Fri Nov 16 23:24:42 2012 +0000

    gnus-diary.el (nndiary-request-create-group-functions, nndiary-request-update-info-functions, gnus-subscribe-newsgroup-functions, nndiary-request-accept-article-functions): Use new names for hooks rather than obsolete aliases

diff --git a/lisp/ChangeLog b/lisp/ChangeLog
index 8bcf198..c1aaf72 100644
--- a/lisp/ChangeLog
+++ b/lisp/ChangeLog
@@ -4,6 +4,14 @@
 	* gnus-logic.el (gnus-advanced-body): Don't score by headers when
 	scoring by body.
 
+2012-11-16  Glenn Morris  <[email protected]>
+
+	* gnus-diary.el (nndiary-request-create-group-functions)
+	(nndiary-request-update-info-functions)
+	(gnus-subscribe-newsgroup-functions)
+	(nndiary-request-accept-article-functions):
+	Use new names for hooks rather than obsolete aliases.
+
 2012-11-14  Katsumi Yamaoka  <[email protected]>
 
 	* dgnushack.el (define-obsolete-variable-alias): Simplify.
diff --git a/lisp/gnus-diary.el b/lisp/gnus-diary.el
index 854af2f..bca307b 100644
--- a/lisp/gnus-diary.el
+++ b/lisp/gnus-diary.el
@@ -277,18 +277,18 @@ Optional prefix (or REVERSE argument) means sort in reverse order."
 
 ;; Called when a group is subscribed. This is needed because groups created
 ;; because of mail splitting are *not* created with the back end function.
 ;; Thus, `nndiary-request-create-group-hooks' is inoperative.
 (defun gnus-diary-maybe-update-group-parameters (group)
   (when (eq (car (gnus-find-method-for-group group)) 'nndiary)
     (gnus-diary-update-group-parameters group)))
 
-(add-hook 'nndiary-request-create-group-hooks
+(add-hook 'nndiary-request-create-group-functions
 	  'gnus-diary-update-group-parameters)
 ;; Now that we have `gnus-subscribe-newsgroup-hooks', this is not needed
 ;; anymore. Maybe I should remove this completely.
-(add-hook 'nndiary-request-update-info-hooks
+(add-hook 'nndiary-request-update-info-functions
 	  'gnus-diary-update-group-parameters)
-(add-hook 'gnus-subscribe-newsgroup-hooks
+(add-hook 'gnus-subscribe-newsgroup-functions
 	  'gnus-diary-maybe-update-group-parameters)
 
 
@@ -384,7 +384,7 @@ If ARG (or prefix) is non-nil, force prompting for all fields."
      nndiary-headers)
     ))
 
-(add-hook 'nndiary-request-accept-article-hooks
+(add-hook 'nndiary-request-accept-article-functions
 	  (lambda () (gnus-diary-check-message nil)))
 
 (define-key message-mode-map "\C-c\C-fd" 'gnus-diary-check-message)

-----------------------------------------------------------------------
@@ -277,18 +277,18 @@ Optional prefix (or REVERSE argument) means sort in reverse order."
 ;; Called when a group is subscribed. This is needed because groups created
 ;; because of mail splitting are *not* created with the back end function.
-;; Thus, `nndiary-request-create-group-hooks' is inoperative.
+;; Thus, `nndiary-request-create-group-functions' is inoperative.
 (defun gnus-diary-maybe-update-group-parameters (group)
   (when (eq (car (gnus-find-method-for-group group)) 'nndiary)
@@ -277,18 +277,18 @@ Optional prefix (or REVERSE argument) means sort in reverse order."
 	  'gnus-diary-update-group-parameters)
-;; Now that we have `gnus-subscribe-newsgroup-hooks', this is not needed
+;; Now that we have `gnus-subscribe-newsgroup-functions', this is not needed
 ;; anymore. Maybe I should remove this completely.
Those revisions listed above that are new to this repository have
not appeared on any other notification email; so we listed those
revisions in full, above.

Summary of changes:
 lisp/ChangeLog     |    8 ++++++++
 lisp/gnus-diary.el |   12 ++++++------
 2 files changed, 14 insertions(+), 6 deletions(-)

This is an automated email from the git hooks/post-receive script. It was
generated because a ref change was pushed to the repository containing
the project "Gnus Project".

The branch, master has been updated


hooks/post-receive
-- 
Gnus Project
lmpx.com only provides a reader for public news (NNTP) servers. It is not affiliated with the servers or forums shown here and is not responsible for the content of articles, which is written by their respective authors.